==> myfaces-core-assembly-1.2.12-src.zip: org/apache/myfaces/el/unified/resolver/implicitobject/FacesContextImplicitObject.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.el.unified.resolver.implicitobject;

import java.beans.FeatureDescriptor;
import javax.el.ELContext;
import javax.faces.context.FacesContext;

/**
 * Encapsulates information needed by the ImplicitObjectResolver
 * 
 * @author Stan Silvert
 */
public class FacesContextImplicitObject extends ImplicitObject
{

    private static final String NAME = "facesContext";

    /** Creates a new instance of FacesContextImplicitObject */
    public FacesContextImplicitObject()
    {
    }

    @Override
    public String getName()
    {
        return NAME;
    }

    @Override
    public Object getValue(ELContext context)
    {
        return facesContext(context);
    }

    @Override
    public Class<?> getType()
    {
        return null;
    }

    @Override
    public FeatureDescriptor getDescriptor()
    {
        return makeDescriptor(NAME, "Per-request information for a JSF request", FacesContext.class);
    }

}

==> myfaces-core-assembly-3.0.1-src.zip: org/apache/myfaces/el/unified/resolver/implicitobject/FacesContextImplicitObject.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.el.unified.resolver.implicitobject;

import java.beans.FeatureDescriptor;
import jakarta.el.ELContext;
import jakarta.faces.context.FacesContext;

/**
 * Encapsulates information needed by the ImplicitObjectResolver
 * 
 * @author Stan Silvert
 */
public class FacesContextImplicitObject extends ImplicitObject
{

    private static final String NAME = "facesContext";

    /** Creates a new instance of FacesContextImplicitObject */
    public FacesContextImplicitObject()
    {
    }

    @Override
    public String getName()
    {
        return NAME;
    }

    @Override
    public Object getValue(ELContext context)
    {
        return facesContext(context);
    }

    @Override
    public Class<?> getType()
    {
        return null;
    }

    @Override
    public FeatureDescriptor getDescriptor()
    {
        return makeDescriptor(NAME, "Per-request information for a JSF request", FacesContext.class);
    }

}
